pub fn render_table_with_theme(result: &ExecutionResult, theme: Theme) -> StringExpand description
Render a table with the given theme. Selects ratatui if the terminal is wide enough, otherwise falls back to the colour-coded plain-text render.
pub fn render_table_with_theme(result: &ExecutionResult, theme: Theme) -> StringRender a table with the given theme. Selects ratatui if the terminal is wide enough, otherwise falls back to the colour-coded plain-text render.